/*
  Name:        	Trace.c
  Author:      	Ron Burkey
  Purpose:     	The processing for Do178Builder-utility 
  		that creates traceability matrices.
  Mod History:	03/14/2008 RSB	Began.
  
  Copyright 2008 Ronald S. Burkey

  This file is part of Do178Builder.

  Do178Builder is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  Do178Builder is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Do178Builder; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  
*/

#include "Do178Builder-utility.h"

typedef void TraceCloseout_t (ProcessingOptions_t *);
TraceCloseout_t TraceDesignCloseout, TraceDesignFullCloseout,
  TraceVerifyCloseout, TraceSystemCloseout, TraceImplementCloseout;

// A function to reset (initialize) the trace-matrix state machine.
void
TraceInitialize (ProcessingOptions_t *Options)
{
  TraceDesign (NULL, Options);
  TraceDesignFull (NULL, Options);
  TraceSystem (NULL, Options);
  TraceImplement (NULL, Options);
  TraceVerify (NULL, Options);
}

// A function to finish up the the trace-matrix state machine.
void
TraceCloseout (ProcessingOptions_t *Options)
{
  TraceDesignCloseout (Options);
  TraceDesignFullCloseout (Options);
  TraceVerifyCloseout (Options);
  TraceSystemCloseout (Options);
  TraceImplementCloseout (Options);
}

// This function does the processing by being called by WalkNodes
// once for each node in the XML tree.  It has to maintain its own
// state machine in order to tie all of these separate calls together,
// and the state machine comprises fields in Options.
int 
Trace (xmlNode *a_node, ProcessingOptions_t *Options)
{
  if (Options->TraceDesign)
    if (TraceDesign (a_node, Options))
      return (1);
  if (Options->TraceDesignFull)
    if (TraceDesignFull (a_node, Options))
      return (1);
  if (Options->TraceSystem)
    if (TraceSystem (a_node, Options))
      return (1);
  if (Options->TraceImplement)
    if (TraceImplement (a_node, Options))
      return (1);
  if (Options->TraceVerify)
    if (TraceVerify (a_node, Options))
      return (1);

  return (0);
}


